[llvm] r360307 - lit config: disable LSan for Apple clang compiler in addition to Apple LLVM

Alex Lorenz via llvm-commits llvm-commits at lists.llvm.org
Wed May 8 19:46:20 PDT 2019


Author: arphaman
Date: Wed May  8 19:46:20 2019
New Revision: 360307

URL: http://llvm.org/viewvc/llvm-project?rev=360307&view=rev
Log:
lit config: disable LSan for Apple clang compiler in addition to Apple LLVM

Apple clang is the canonical way to refer to the compiler shipped with Xcode.

Modified:
    llvm/trunk/utils/lit/lit/llvm/config.py

Modified: llvm/trunk/utils/lit/lit/llvm/config.py
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/utils/lit/lit/llvm/config.py?rev=360307&r1=360306&r2=360307&view=diff
==============================================================================
--- llvm/trunk/utils/lit/lit/llvm/config.py (original)
+++ llvm/trunk/utils/lit/lit/llvm/config.py Wed May  8 19:46:20 2019
@@ -233,8 +233,8 @@ class LLVMConfig(object):
             major_version_number = int(version_regex.group(1))
             minor_version_number = int(version_regex.group(2))
             patch_version_number = int(version_regex.group(3))
-            if 'Apple LLVM' in version_string:
-                # Apple LLVM doesn't yet support LSan
+            if ('Apple LLVM' in version_string) or ('Apple clang' in version_string):
+                # Apple clang doesn't yet support LSan
                 return False
             else:
                 return major_version_number >= 5




More information about the llvm-commits mailing list